import Taro from '@tarojs/taro';
import { createApp } from 'vue';
import bannerAd from '@/components/ad/bannerAd.vue'
import aLayout from '@/layout/aLayout.vue'
import './app.less';
import { login, updatePerson } from './service/person';
import store from './store';

const App = createApp({
  onShow (options) {
    const { query } = options;
    const { recommender } = query || {}

    Taro.login({
      success (res) {
        if (res.code) {
          login({ code: res.code, recommender }).then(res => {
            const { setUser } = store.getState('user');
            const { person } = res;
            setUser(person);

            Taro.getLocation({
              type: 'wgs84', // gps
              success: ({ longitude, latitude }) => {
                const location = `${longitude},${latitude}`
                updatePerson({ ...person, location })
              }
            })
            
          })
        } else {
          console.log('登录失败！' + res.errMsg)
        }
      }
    })
  },
  // 入口组件不需要实现 render 方法，即使实现了也会被 taro 所覆盖
});

App.use(store);
App.component('banner-ad', bannerAd);
App.component('a-layout', aLayout);

export default App
