
import { ref, onMounted } from 'vue';
// import Taro, { useReady } from '@tarojs/taro';

export default function useCanvas(size = 160) {
  const cvsRef = ref();
  const ctxRef = ref();

  onMounted(() => {
    const canvas = wx.createOffscreenCanvas({type: '2d', width: size, height: size});
    const ctx = canvas.getContext('2d');
    
    cvsRef.value = canvas;
    ctxRef.value = ctx;
  });

  const reset = () => {
    ctxRef.value.clearRect(0, 0, size, size);
  }

  const drawImage = (url, ...args) => {
    const canvas = cvsRef.value;
    const ctx = ctxRef.value;

    return new Promise((resolve, reject) => {      
      wx.getImageInfo({
        src: url,
        success: ({ width, height }) => {
          const image = canvas.createImage();
          image.onload = () => {
            ctx.drawImage(image, 0, 0, width, height, ...args);
            resolve();
          };
          image.onerror = (err) => {
            console.error(err)
            reject(err)
          };
          image.src = url;
        },
        fail: (err) => {
          console.error(err)
          reject(err)
        },
      });
    });
  }

  const toTempFile = ({ success, fail, complete }) => {
    const dataStr = toDataURL();
    const fs = wx.getFileSystemManager();
    const tm = new Date().getTime();
    const filePath = `${wx.env.USER_DATA_PATH}/tmp_avatar_${tm}.jpg`;

    fs.writeFile({
      filePath,
      data: dataStr.split('base64,')[1],
      encoding: 'base64',
      success: () => {
        if (success) {
          success(filePath);
        }
      },
      fail: (err) => {
        console.error(err);
        if (fail) {
          fail(err);
        }
      },
      complete: () => {
        if (complete) {
          complete();
        }
      }
    })
  }

  const toDataURL = (type = 'image/jpeg', encoderOptions = 0.9) => {
    const canvas = cvsRef.value;
    return canvas.toDataURL(type, encoderOptions);
  }

  return [
    drawImage,
    toDataURL,
    toTempFile,
    reset,
    cvsRef,
    ctxRef,
  ];
}
