import Taro from '@tarojs/taro';
import { getToken, setToken } from './token';
import logger from './log';

const getQueryStrByParams = params => {
  if (!params) return undefined;

  return Object.keys(params).map(key => {
    const value = params[key];
    return `${encodeURIComponent(key)}=${encodeURIComponent(value)}`
  }).join('&')
}

export default function request(api, options = {}) {
  return new Promise((resolve, reject) => {
    const onError = (err) => {
      console.error(err);
      logger.error(`接口 [${method}]: ${url}`);
      logger.error('参数: ', data);
      logger.error(err);
      reject(err);
    };

    const { method = 'GET', params, data = {}, header = {}, ...cfgs } = options;
    const queryStr = params ? getQueryStrByParams(params) : undefined;
    const url = queryStr ? `${HOST}${api}?${queryStr}` : `${HOST}${api}`

    Taro.request({
      url,
      data,
      method,
      header: {
        'content-type': 'application/json',
        'authorization': getToken(),
        ...header,
      },
      ...cfgs,
    }).then(({ statusCode, header, data = result }) => {
      if (statusCode >= 300) {
        logger.error(header);
        return onError(`网络错误 ${statusCode}`);
      }

      if (data.code === 1000) {
        if (data.data.token) {
          setToken(data.data.token);
        }

        resolve(data.data);
      } else {
        onError(data);
      }
    }).catch(onError);

  });
}
